@@ -7,7 +7,7 @@ Wave terrain synthesis of a live recording of FM synthesis in the matrix.
 """
 from pyo import *
 
-s = Server(sr=44100, nchnls=2, buffersize=512, duplex=0).boot()
+s = Server(duplex=0).boot()
 
 SIZE = 256
 mm = NewMatrix(SIZE, SIZE)
