@@ -7,7 +7,7 @@ methods to sequence events over time.
 """
 from pyo import *
 
-s = Server(sr=44100, nchnls=2, buffersize=512, duplex=0).boot()
+s = Server(duplex=0).boot()
 
 num = 70
 freqs = [random.uniform(100,1000) for i in range(num)]
