@@ -21,7 +21,7 @@
 #include "Python.h"
 #include <math.h>
 
-#define PYO_VERSION "0.9.0"
+#define PYO_VERSION "0.9.1"
 
 #ifndef __MYFLT_DEF
 #define __MYFLT_DEF
@@ -526,6 +526,8 @@ extern PyTypeObject HRTFType;
 extern PyTypeObject ExpandType;
 extern PyTypeObject RMSType;
 extern PyTypeObject MidiLinsegType;
+extern PyTypeObject MultiBandMainType;
+extern PyTypeObject MultiBandType;
 
 /* Constants */
 #define E M_E
@@ -1649,7 +1651,7 @@ extern PyTypeObject MidiLinsegType;
     if (dur == 0) \
         Stream_setDuration(self->stream, 0); \
     else { \
-        nearestBuf = (int)roundf((dur * self->sr) / self->bufsize); \
+        nearestBuf = (int)roundf((dur * self->sr) / self->bufsize + 0.5); \
         Stream_setDuration(self->stream, nearestBuf); \
     } \
     Py_INCREF(self); \
@@ -1693,7 +1695,7 @@ extern PyTypeObject MidiLinsegType;
     if (dur == 0) \
         Stream_setDuration(self->stream, 0); \
     else { \
-        nearestBuf = (int)roundf((dur * self->sr) / self->bufsize); \
+        nearestBuf = (int)roundf((dur * self->sr) / self->bufsize + 0.5); \
         Stream_setDuration(self->stream, nearestBuf); \
     } \
     Py_INCREF(self); \
@@ -1825,7 +1827,7 @@ extern PyTypeObject MidiLinsegType;
 #if PY_MAJOR_VERSION < 3
 #define TABLESTREAM_READ_WRITE_BUFFER \
     if ( index != 0 ) { \
-        PySys_WriteStdout("Accessing non-existent bytes segment..."); \
+        PySys_WriteStdout("Pyo error: Table buffer, accessing non-existent bytes segment."); \
         return -1; \
     } \
     *ptr = (void *)self->data; \
@@ -1839,7 +1841,7 @@ extern PyTypeObject MidiLinsegType;
 
 #define TABLESTREAM_GET_BUFFER \
     if (view == NULL) { \
-        PySys_WriteStdout("NULL view in getBuffer."); \
+        PySys_WriteStdout("Pyo error: Table buffer, NULL view in getBuffer."); \
         return -1; \
     } \
     self->shape[0] = self->size; \
