@@ -88,7 +88,8 @@ OBJECTS_TREE = {
                          'linToCosCurve', 'convertStringToSysEncoding', 
                          'savefileFromTable', 'pa_get_input_max_channels', 
                          'pa_get_output_max_channels', 'pa_get_devices_infos', 
-                         'pa_get_version', 'pa_get_version_text', 'floatmap']),
+                         'pa_get_version', 'pa_get_version_text', 'floatmap',
+                         'getPrecision']),
     'PyoObjectBase': {
         'PyoMatrixObject': sorted(['NewMatrix']),
         'PyoTableObject': sorted(['LinTable', 'NewTable', 'SndTable', 
@@ -124,7 +125,7 @@ OBJECTS_TREE = {
                                'Biquadx', 'IRWinSinc', 'IRAverage', 'IRPulse', 
                                'IRFM', 'FourBand', 'Biquada', 'Atone', 'SVF', 
                                'Average', 'Reson', 'Resonx', 'ButLP', 'ButHP', 
-                               'ButBP', 'ButBR', 'ComplexRes', 'MoogLP']),
+                               'ButBP', 'ButBR', 'ComplexRes', 'MoogLP', 'MultiBand']),
             'generators': sorted(['Noise', 'Phasor', 'Sine', 'Input', 'CrossFM', 
                                   'SineLoop', 'Blit', 'PinkNoise', 'FM', 'LFO', 
                                   'BrownNoise', 'Rossler', 'Lorenz', 'ChenLee', 
