@@ -1324,7 +1324,7 @@ class Scope(PyoObject):
         self._in_fader = InputFader(input)
         in_fader, lmax = convertArgsToLists(self._in_fader)
         self._base_objs = [Scope_base(wrap(in_fader,i), length) for i in range(lmax)]
-        self._timer = Pattern(self.refreshView, length).play()
+        self._base_objs[0].setFunc(self.refreshView)
         if function is None:
             self.view(wintitle)
         self.play()
@@ -1357,7 +1357,6 @@ class Scope(PyoObject):
         """
         pyoArgsAssert(self, "N", x)
         self._length = x
-        self._timer.time = x
         [obj.setLength(x) for obj in self._base_objs]
 
     def setGain(self, x):
@@ -1387,10 +1386,7 @@ class Scope(PyoObject):
 
         """
         pyoArgsAssert(self, "B", active)
-        if active:
-            self._timer.play()
-        else:
-            self._timer.stop()
+        [obj.setPoll(active) for obj in self._base_objs]
 
     def setWidth(self, x):
         """
@@ -1515,7 +1511,7 @@ class PeakAmp(PyoObject):
     Output signal is the continuous peak amplitude of an input signal.
     A new peaking value is computed every buffer size. If `function`
     argument is not None, it should be a function that will be called
-    every buffer size with a variable-length argument list containing
+    periodically with a variable-length argument list containing
     the peaking values of all object's streams. Useful for meter drawing.
     Function definition must look like this:
 
@@ -1627,3 +1623,123 @@ class PeakAmp(PyoObject):
         return self._function
     @function.setter
     def function(self, x): self.setFunction(x)
+
+class RMS(PyoObject):
+    """
+    Returns the RMS (Root-Mean-Square) value of a signal.
+
+    Output signal is the continuous rms of an input signal. A new rms 
+    value is computed every buffer size. If `function` argument is not 
+    None, it should be a function that will be called periodically 
+    with a variable-length argument list containing the rms values 
+    of all object's streams. Useful for meter drawing. Function 
+    definition must look like this:
+
+    >>> def getValues(*args)
+
+    :Parent: :py:class:`PyoObject`
+
+    :Args:
+
+        input: PyoObject
+            Input signal to process.
+        function: callable, optional
+            Function that will be called with amplitude values in arguments.
+            Default to None.
+
+    .. note::
+
+        The out() method is bypassed. RMS's signal can not be sent to
+        audio outs.
+
+    >>> s = Server().boot()
+    >>> s.start()
+    >>> sf = SfPlayer(SNDS_PATH + "/transparent.aif", loop=True, mul=.4).out()
+    >>> amp = RMS(sf)
+    >>> n = Noise(mul=Port(amp)).out(1)
+
+    """
+    def __init__(self, input, function=None, mul=1, add=0):
+        pyoArgsAssert(self, "oCOO", input, function, mul, add)
+        PyoObject.__init__(self, mul, add)
+        self._input = input
+        if callable(function):
+            self._function = getWeakMethodRef(function)
+        else:
+            self._function = None
+        self._in_fader = InputFader(input)
+        in_fader, mul, add, lmax = convertArgsToLists(self._in_fader, mul, add)
+        self._base_objs = [RMS_base(wrap(in_fader,i), wrap(mul,i), wrap(add,i)) for i in range(lmax)]
+        sr = self.getSamplingRate()
+        bs = self.getBufferSize()
+        self._timer = Pattern(self._buildList, 0.06).play()
+        self.play()
+
+    def setInput(self, x, fadetime=0.05):
+        """
+        Replace the `input` attribute.
+
+        :Args:
+
+            x: PyoObject
+                New signal to process.
+            fadetime: float, optional
+                Crossfade time between old and new input. Default to 0.05.
+
+        """
+        pyoArgsAssert(self, "oN", x, fadetime)
+        self._input = x
+        self._in_fader.setInput(x, fadetime)
+
+    def setFunction(self, x):
+        """
+        Replace the `function` attribute.
+
+        :Args:
+
+            x: callable
+                New function to call with amplitude values in arguments.
+
+        """
+        pyoArgsAssert(self, "C", x)
+        if callable(x):
+            self._function = getWeakMethodRef(x)
+
+    def polltime(self, x):
+        """
+        Sets the delay, in seconds, between each call of the function.
+
+        :Args:
+
+            x: float
+                New polling time in seconds.
+
+        """
+        pyoArgsAssert(self, "N", x)
+        self._timer.time = x
+
+    def out(self, chnl=0, inc=1, dur=0, delay=0):
+        return self.play(dur, delay)
+
+    def _buildList(self):
+        if self._function is not None:
+            values = [obj.getValue() for obj in self._base_objs]
+            self._function(*values)
+
+    def ctrl(self, map_list=None, title=None, wxnoserver=False):
+        self._map_list = []
+        PyoObject.ctrl(self, map_list, title, wxnoserver)
+
+    @property
+    def input(self):
+        """PyoObject. Input signal to process."""
+        return self._input
+    @input.setter
+    def input(self, x): self.setInput(x)
+
+    @property
+    def function(self):
+        """PyoObject. function signal to process."""
+        return self._function
+    @function.setter
+    def function(self, x): self.setFunction(x)
