@@ -1,24 +1,25 @@
-/*************************************************************************
- * Copyright 2010 Olivier Belanger                                        *                  
- *                                                                        * 
+/**************************************************************************
+ * Copyright 2009-2015 Olivier Belanger                                   *
+ *                                                                        *
  * This file is part of pyo, a python module to help digital signal       *
- * processing script creation.                                            *  
- *                                                                        * 
+ * processing script creation.                                            *
+ *                                                                        *
  * pyo is free software: you can redistribute it and/or modify            *
- * it under the terms of the GNU General Public License as published by   *
- * the Free Software Foundation, either version 3 of the License, or      *
- * (at your option) any later version.                                    * 
+ * it under the terms of the GNU Lesser General Public License as         *
+ * published by the Free Software Foundation, either version 3 of the     *
+ * License, or (at your option) any later version.                        *
  *                                                                        *
  * pyo is distributed in the hope that it will be useful,                 *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of         *    
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of         *
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- * GNU General Public License for more details.                           *
+ * GNU Lesser General Public License for more details.                    *
  *                                                                        *
- * You should have received a copy of the GNU General Public License      *
- * along with pyo.  If not, see <http://www.gnu.org/licenses/>.           *
+ * You should have received a copy of the GNU Lesser General Public       *
+ * License along with pyo.  If not, see <http://www.gnu.org/licenses/>.   *
  *************************************************************************/
 
 #include <Python.h>
+#include "py2to3.h"
 #include "structmember.h"
 #include "pyomodule.h"
 #include "streammodule.h"
@@ -48,46 +49,46 @@ Input_setProcMode(Input *self)
     muladdmode = self->modebuffer[0] + self->modebuffer[1] * 10;
 
 	switch (muladdmode) {
-        case 0:        
+        case 0:
             self->muladd_func_ptr = Input_postprocessing_ii;
             break;
-        case 1:    
+        case 1:
             self->muladd_func_ptr = Input_postprocessing_ai;
             break;
-        case 2:    
+        case 2:
             self->muladd_func_ptr = Input_postprocessing_revai;
             break;
-        case 10:        
+        case 10:
             self->muladd_func_ptr = Input_postprocessing_ia;
             break;
-        case 11:    
+        case 11:
             self->muladd_func_ptr = Input_postprocessing_aa;
             break;
-        case 12:    
+        case 12:
             self->muladd_func_ptr = Input_postprocessing_revaa;
             break;
-        case 20:        
+        case 20:
             self->muladd_func_ptr = Input_postprocessing_ireva;
             break;
-        case 21:    
+        case 21:
             self->muladd_func_ptr = Input_postprocessing_areva;
             break;
-        case 22:    
+        case 22:
             self->muladd_func_ptr = Input_postprocessing_revareva;
             break;
-    } 
+    }
 }
 
 static void
 Input_compute_next_data_frame(Input *self)
-{   
+{
     int i;
     MYFLT *tmp;
     tmp = Server_getInputBuffer((Server *)self->server);
-    for (i=0; i<self->bufsize*self->nchnls; i++) {
-        if ((i % self->nchnls) == self->chnl)
-            self->data[(int)(i/self->nchnls)] = tmp[i];
-    }    
+    for (i=0; i<self->bufsize*self->ichnls; i++) {
+        if ((i % self->ichnls) == self->chnl)
+            self->data[(int)(i/self->ichnls)] = tmp[i];
+    }
     (*self->muladd_func_ptr)(self);
 }
 
@@ -98,7 +99,7 @@ Input_traverse(Input *self, visitproc visit, void *arg)
     return 0;
 }
 
-static int 
+static int
 Input_clear(Input *self)
 {
     pyo_CLEAR
@@ -110,7 +111,7 @@ Input_dealloc(Input* self)
 {
     pyo_DEALLOC
     Input_clear(self);
-    self->ob_type->tp_free((PyObject*)self);
+    Py_TYPE(self)->tp_free((PyObject*)self);
 }
 
 static PyObject *
@@ -133,7 +134,7 @@ Input_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
 
     if (! PyArg_ParseTupleAndKeywords(args, kwds, "|iOO", kwlist, &self->chnl, &multmp, &addtmp))
         Py_RETURN_NONE;
- 
+
     if (multmp) {
         PyObject_CallMethod((PyObject *)self, "setMul", "O", multmp);
     }
@@ -141,20 +142,20 @@ Input_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
     if (addtmp) {
         PyObject_CallMethod((PyObject *)self, "setAdd", "O", addtmp);
     }
-            
+
     PyObject_CallMethod(self->server, "addStream", "O", self->stream);
 
     (*self->mode_func_ptr)(self);
-    
+
     return (PyObject *)self;
 }
 
 static PyObject * Input_getServer(Input* self) { GET_SERVER };
 static PyObject * Input_getStream(Input* self) { GET_STREAM };
-static PyObject * Input_setMul(Input *self, PyObject *arg) { SET_MUL };	
-static PyObject * Input_setAdd(Input *self, PyObject *arg) { SET_ADD };	
-static PyObject * Input_setSub(Input *self, PyObject *arg) { SET_SUB };	
-static PyObject * Input_setDiv(Input *self, PyObject *arg) { SET_DIV };	
+static PyObject * Input_setMul(Input *self, PyObject *arg) { SET_MUL };
+static PyObject * Input_setAdd(Input *self, PyObject *arg) { SET_ADD };
+static PyObject * Input_setSub(Input *self, PyObject *arg) { SET_SUB };
+static PyObject * Input_setDiv(Input *self, PyObject *arg) { SET_DIV };
 
 static PyObject * Input_play(Input *self, PyObject *args, PyObject *kwds) { PLAY };
 static PyObject * Input_out(Input *self, PyObject *args, PyObject *kwds) { OUT };
@@ -194,7 +195,7 @@ static PyNumberMethods Input_as_number = {
     (binaryfunc)Input_add,                      /*nb_add*/
     (binaryfunc)Input_sub,                 /*nb_subtract*/
     (binaryfunc)Input_multiply,                 /*nb_multiply*/
-    (binaryfunc)Input_div,                   /*nb_divide*/
+    INITIALIZE_NB_DIVIDE_ZERO               /*nb_divide*/
     0,                /*nb_remainder*/
     0,                   /*nb_divmod*/
     0,                   /*nb_power*/
@@ -208,16 +209,16 @@ static PyNumberMethods Input_as_number = {
     0,              /*nb_and*/
     0,              /*nb_xor*/
     0,               /*nb_or*/
-    0,                                          /*nb_coerce*/
+    INITIALIZE_NB_COERCE_ZERO                   /*nb_coerce*/
     0,                       /*nb_int*/
     0,                      /*nb_long*/
     0,                     /*nb_float*/
-    0,                       /*nb_oct*/
-    0,                       /*nb_hex*/
+    INITIALIZE_NB_OCT_ZERO   /*nb_oct*/
+    INITIALIZE_NB_HEX_ZERO   /*nb_hex*/
     (binaryfunc)Input_inplace_add,              /*inplace_add*/
     (binaryfunc)Input_inplace_sub,         /*inplace_subtract*/
     (binaryfunc)Input_inplace_multiply,         /*inplace_multiply*/
-    (binaryfunc)Input_inplace_div,           /*inplace_divide*/
+    INITIALIZE_NB_IN_PLACE_DIVIDE_ZERO        /*inplace_divide*/
     0,        /*inplace_remainder*/
     0,           /*inplace_power*/
     0,       /*inplace_lshift*/
@@ -226,15 +227,14 @@ static PyNumberMethods Input_as_number = {
     0,      /*inplace_xor*/
     0,       /*inplace_or*/
     0,             /*nb_floor_divide*/
-    0,              /*nb_true_divide*/
+    (binaryfunc)Input_div,                       /*nb_true_divide*/
     0,     /*nb_inplace_floor_divide*/
-    0,      /*nb_inplace_true_divide*/
+    (binaryfunc)Input_inplace_div,                       /*nb_inplace_true_divide*/
     0,                     /* nb_index */
 };
 
 PyTypeObject InputType = {
-    PyObject_HEAD_INIT(NULL)
-    0,                         /*ob_size*/
+    PyVarObject_HEAD_INIT(NULL, 0)
     "_pyo.Input_base",         /*tp_name*/
     sizeof(Input),         /*tp_basicsize*/
     0,                         /*tp_itemsize*/
@@ -242,7 +242,7 @@ PyTypeObject InputType = {
     0,                         /*tp_print*/
     0,                         /*tp_getattr*/
     0,                         /*tp_setattr*/
-    0,                         /*tp_compare*/
+    0,                         /*tp_as_async (tp_compare in Python 2)*/
     0,                         /*tp_repr*/
     &Input_as_number,             /*tp_as_number*/
     0,                         /*tp_as_sequence*/
@@ -273,4 +273,3 @@ PyTypeObject InputType = {
     0,                         /* tp_alloc */
     Input_new,                 /* tp_new */
 };
-
