@@ -19,6 +19,7 @@
  *************************************************************************/
 
 #include <Python.h>
+#include "py2to3.h"
 #include "structmember.h"
 #include "pyomodule.h"
 #include "streammodule.h"
@@ -136,7 +137,7 @@ MatrixPointer_dealloc(MatrixPointer* self)
 {
     pyo_DEALLOC
     MatrixPointer_clear(self);
-    self->ob_type->tp_free((PyObject*)self);
+    Py_TYPE(self)->tp_free((PyObject*)self);
 }
 
 static PyObject *
@@ -219,10 +220,7 @@ MatrixPointer_setMatrix(MatrixPointer *self, PyObject *arg)
 {
 	PyObject *tmp;
 
-	if (arg == NULL) {
-		Py_INCREF(Py_None);
-		return Py_None;
-	}
+    ASSERT_ARG_NOT_NULL
 
 	tmp = arg;
     if ( PyObject_HasAttrString((PyObject *)tmp, "getMatrixStream") == 0 ) {
@@ -242,10 +240,7 @@ MatrixPointer_setX(MatrixPointer *self, PyObject *arg)
 {
 	PyObject *tmp, *streamtmp;
 
-	if (arg == NULL) {
-		Py_INCREF(Py_None);
-		return Py_None;
-	}
+    ASSERT_ARG_NOT_NULL
 
 	tmp = arg;
 
@@ -272,10 +267,7 @@ MatrixPointer_setY(MatrixPointer *self, PyObject *arg)
 {
 	PyObject *tmp, *streamtmp;
 
-	if (arg == NULL) {
-		Py_INCREF(Py_None);
-		return Py_None;
-	}
+    ASSERT_ARG_NOT_NULL
 
 	tmp = arg;
 
@@ -329,7 +321,7 @@ static PyNumberMethods MatrixPointer_as_number = {
 (binaryfunc)MatrixPointer_add,                      /*nb_add*/
 (binaryfunc)MatrixPointer_sub,                 /*nb_subtract*/
 (binaryfunc)MatrixPointer_multiply,                 /*nb_multiply*/
-(binaryfunc)MatrixPointer_div,                   /*nb_divide*/
+INITIALIZE_NB_DIVIDE_ZERO               /*nb_divide*/
 0,                /*nb_remainder*/
 0,                   /*nb_divmod*/
 0,                   /*nb_power*/
@@ -343,16 +335,16 @@ static PyNumberMethods MatrixPointer_as_number = {
 0,              /*nb_and*/
 0,              /*nb_xor*/
 0,               /*nb_or*/
-0,                                          /*nb_coerce*/
+INITIALIZE_NB_COERCE_ZERO                   /*nb_coerce*/
 0,                       /*nb_int*/
 0,                      /*nb_long*/
 0,                     /*nb_float*/
-0,                       /*nb_oct*/
-0,                       /*nb_hex*/
+INITIALIZE_NB_OCT_ZERO   /*nb_oct*/
+INITIALIZE_NB_HEX_ZERO   /*nb_hex*/
 (binaryfunc)MatrixPointer_inplace_add,              /*inplace_add*/
 (binaryfunc)MatrixPointer_inplace_sub,         /*inplace_subtract*/
 (binaryfunc)MatrixPointer_inplace_multiply,         /*inplace_multiply*/
-(binaryfunc)MatrixPointer_inplace_div,           /*inplace_divide*/
+INITIALIZE_NB_IN_PLACE_DIVIDE_ZERO        /*inplace_divide*/
 0,        /*inplace_remainder*/
 0,           /*inplace_power*/
 0,       /*inplace_lshift*/
@@ -361,15 +353,14 @@ static PyNumberMethods MatrixPointer_as_number = {
 0,      /*inplace_xor*/
 0,       /*inplace_or*/
 0,             /*nb_floor_divide*/
-0,              /*nb_true_divide*/
+(binaryfunc)MatrixPointer_div,                       /*nb_true_divide*/
 0,     /*nb_inplace_floor_divide*/
-0,      /*nb_inplace_true_divide*/
+(binaryfunc)MatrixPointer_inplace_div,                       /*nb_inplace_true_divide*/
 0,                     /* nb_x */
 };
 
 PyTypeObject MatrixPointerType = {
-PyObject_HEAD_INIT(NULL)
-0,                         /*ob_size*/
+PyVarObject_HEAD_INIT(NULL, 0)
 "_pyo.MatrixPointer_base",         /*tp_name*/
 sizeof(MatrixPointer),         /*tp_basicsize*/
 0,                         /*tp_itemsize*/
@@ -377,7 +368,7 @@ sizeof(MatrixPointer),         /*tp_basicsize*/
 0,                         /*tp_print*/
 0,                         /*tp_getattr*/
 0,                         /*tp_setattr*/
-0,                         /*tp_compare*/
+0,                         /*tp_as_async (tp_compare in Python 2)*/
 0,                         /*tp_repr*/
 &MatrixPointer_as_number,             /*tp_as_number*/
 0,                         /*tp_as_sequence*/
