@@ -19,6 +19,7 @@
  *************************************************************************/
 
 #include <Python.h>
+#include "py2to3.h"
 #include "structmember.h"
 #include "pyomodule.h"
 #include "streammodule.h"
@@ -121,7 +122,7 @@ Sig_dealloc(Sig* self)
 {
     pyo_DEALLOC
     Sig_clear(self);
-    self->ob_type->tp_free((PyObject*)self);
+    Py_TYPE(self)->tp_free((PyObject*)self);
 }
 
 static PyObject *
@@ -172,10 +173,7 @@ Sig_setValue(Sig *self, PyObject *arg)
 {
 	PyObject *tmp, *streamtmp;
 
-	if (arg == NULL) {
-		Py_INCREF(Py_None);
-		return Py_None;
-	}
+    ASSERT_ARG_NOT_NULL
 
 	int isNumber = PyNumber_Check(arg);
 
@@ -246,7 +244,7 @@ static PyNumberMethods Sig_as_number = {
 (binaryfunc)Sig_add,                      /*nb_add*/
 (binaryfunc)Sig_sub,                 /*nb_subtract*/
 (binaryfunc)Sig_multiply,                 /*nb_multiply*/
-(binaryfunc)Sig_div,                   /*nb_divide*/
+INITIALIZE_NB_DIVIDE_ZERO               /*nb_divide*/
 0,                /*nb_remainder*/
 0,                   /*nb_divmod*/
 0,                   /*nb_power*/
@@ -260,16 +258,16 @@ static PyNumberMethods Sig_as_number = {
 0,              /*nb_and*/
 0,              /*nb_xor*/
 0,               /*nb_or*/
-0,                                          /*nb_coerce*/
+INITIALIZE_NB_COERCE_ZERO                   /*nb_coerce*/
 0,                       /*nb_int*/
 0,                      /*nb_long*/
 0,                     /*nb_float*/
-0,                       /*nb_oct*/
-0,                       /*nb_hex*/
+INITIALIZE_NB_OCT_ZERO   /*nb_oct*/
+INITIALIZE_NB_HEX_ZERO   /*nb_hex*/
 (binaryfunc)Sig_inplace_add,              /*inplace_add*/
 (binaryfunc)Sig_inplace_sub,         /*inplace_subtract*/
 (binaryfunc)Sig_inplace_multiply,         /*inplace_multiply*/
-(binaryfunc)Sig_inplace_div,           /*inplace_divide*/
+INITIALIZE_NB_IN_PLACE_DIVIDE_ZERO        /*inplace_divide*/
 0,        /*inplace_remainder*/
 0,           /*inplace_power*/
 0,       /*inplace_lshift*/
@@ -278,15 +276,14 @@ static PyNumberMethods Sig_as_number = {
 0,      /*inplace_xor*/
 0,       /*inplace_or*/
 0,             /*nb_floor_divide*/
-0,              /*nb_true_divide*/
+(binaryfunc)Sig_div,                       /*nb_true_divide*/
 0,     /*nb_inplace_floor_divide*/
-0,      /*nb_inplace_true_divide*/
+(binaryfunc)Sig_inplace_div,                       /*nb_inplace_true_divide*/
 0,                     /* nb_index */
 };
 
 PyTypeObject SigType = {
-PyObject_HEAD_INIT(NULL)
-0,                         /*ob_size*/
+PyVarObject_HEAD_INIT(NULL, 0)
 "_pyo.Sig_base",         /*tp_name*/
 sizeof(Sig),         /*tp_basicsize*/
 0,                         /*tp_itemsize*/
@@ -294,7 +291,7 @@ sizeof(Sig),         /*tp_basicsize*/
 0,                         /*tp_print*/
 0,                         /*tp_getattr*/
 0,                         /*tp_setattr*/
-0,                         /*tp_compare*/
+0,                         /*tp_as_async (tp_compare in Python 2)*/
 0,                         /*tp_repr*/
 &Sig_as_number,             /*tp_as_number*/
 0,                         /*tp_as_sequence*/
@@ -333,26 +330,33 @@ typedef struct {
     pyo_audio_HEAD
     PyObject *value;
     Stream *value_stream;
+    PyObject *time;
+    Stream *time_stream;
     MYFLT lastValue;
     MYFLT currentValue;
-    MYFLT time;
     long timeStep;
     MYFLT stepVal;
     long timeCount;
-    int modebuffer[3];
+    int modebuffer[4];
 } SigTo;
 
 static void
 SigTo_generates_i(SigTo *self) {
     int i;
-    MYFLT value;
+    MYFLT value, time;
+
     if (self->modebuffer[2] == 0) {
         value = PyFloat_AS_DOUBLE(self->value);
         if (value != self->lastValue) {
+            if (self->modebuffer[3] == 0)
+                time = PyFloat_AS_DOUBLE(self->time);
+            else
+                time = Stream_getData((Stream *)self->time_stream)[0];
             self->timeCount = 0;
-            self->timeStep = (long)(self->time * self->sr);
-            self->stepVal = (value - self->currentValue) / self->timeStep;
             self->lastValue = value;
+            self->timeStep = (long)(time * self->sr);
+            if (self->timeStep > 0)
+                self->stepVal = (value - self->currentValue) / self->timeStep;
         }
         if (self->timeStep <= 0) {
             for (i=0; i<self->bufsize; i++)
@@ -372,24 +376,24 @@ SigTo_generates_i(SigTo *self) {
             }
         }
     }
-    else {
+    else { 
         MYFLT *vals = Stream_getData((Stream *)self->value_stream);
-        if (self->timeStep <= 0) {
-            for (i=0; i<self->bufsize; i++) {
-                value = vals[i];
-                self->data[i] = self->currentValue = self->lastValue = value;
-            }
-        }
-        else {
-            for (i=0; i<self->bufsize; i++) {
-                value = vals[i];
-                if (value != self->lastValue) {
-                    self->timeCount = 0;
-                    self->timeStep = (long)(self->time * self->sr);
+        for (i=0; i<self->bufsize; i++) {
+            value = vals[i];
+            if (value != self->lastValue) {
+                if (self->modebuffer[3] == 0)
+                    time = PyFloat_AS_DOUBLE(self->time);
+                else
+                    time = Stream_getData((Stream *)self->time_stream)[i];
+                self->timeCount = 0;
+                self->lastValue = value;
+                self->timeStep = (long)(time * self->sr);
+                if (self->timeStep > 0)
                     self->stepVal = (value - self->currentValue) / self->timeStep;
-                    self->lastValue = value;
-                }
-
+            }
+            if (self->timeStep <= 0) {
+                self->data[i] = self->currentValue = self->lastValue = value;
+            } else {
                 if (self->timeCount == (self->timeStep - 1)) {
                     self->currentValue = value;
                     self->timeCount++;
@@ -466,6 +470,8 @@ SigTo_traverse(SigTo *self, visitproc visit, void *arg)
     pyo_VISIT
     Py_VISIT(self->value);
     Py_VISIT(self->value_stream);
+    Py_VISIT(self->time);
+    Py_VISIT(self->time_stream);
     return 0;
 }
 
@@ -475,6 +481,8 @@ SigTo_clear(SigTo *self)
     pyo_CLEAR
     Py_CLEAR(self->value);
     Py_CLEAR(self->value_stream);
+    Py_CLEAR(self->time);
+    Py_CLEAR(self->time_stream);
     return 0;
 }
 
@@ -483,7 +491,7 @@ SigTo_dealloc(SigTo* self)
 {
     pyo_DEALLOC
     SigTo_clear(self);
-    self->ob_type->tp_free((PyObject*)self);
+    Py_TYPE(self)->tp_free((PyObject*)self);
 }
 
 static PyObject *
@@ -496,12 +504,14 @@ SigTo_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
     self = (SigTo *)type->tp_alloc(type, 0);
 
     self->value = PyFloat_FromDouble(0.0);
-    self->time = 0.025;
+    self->time = PyFloat_FromDouble(0.025);
     self->timeCount = 0;
     self->stepVal = 0.0;
+    self->timeStep = 0;
 	self->modebuffer[0] = 0;
 	self->modebuffer[1] = 0;
 	self->modebuffer[2] = 0;
+	self->modebuffer[3] = 0;
 
     INIT_OBJECT_COMMON
     Stream_setFunctionPtr(self->stream, SigTo_compute_next_data_frame);
@@ -531,7 +541,6 @@ SigTo_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
     PyObject_CallMethod(self->server, "addStream", "O", self->stream);
 
     self->lastValue = self->currentValue = inittmp;
-    self->timeStep = (long)(self->time * self->sr);
 
     (*self->mode_func_ptr)(self);
 
@@ -547,10 +556,7 @@ SigTo_setValue(SigTo *self, PyObject *arg)
 {
 	PyObject *tmp, *streamtmp;
 
-	if (arg == NULL) {
-		Py_INCREF(Py_None);
-		return Py_None;
-	}
+    ASSERT_ARG_NOT_NULL
 
 	int isNumber = PyNumber_Check(arg);
 
@@ -570,30 +576,35 @@ SigTo_setValue(SigTo *self, PyObject *arg)
         self->modebuffer[2] = 1;
     }
 
-	Py_INCREF(Py_None);
-	return Py_None;
+	Py_RETURN_NONE;
 }
 
 static PyObject *
 SigTo_setTime(SigTo *self, PyObject *arg)
 {
-	PyObject *tmp;
+	PyObject *tmp, *streamtmp;
 
-	if (arg == NULL) {
-		Py_INCREF(Py_None);
-		return Py_None;
-	}
+    ASSERT_ARG_NOT_NULL
 
 	int isNumber = PyNumber_Check(arg);
 
 	tmp = arg;
 	Py_INCREF(tmp);
+    Py_DECREF(self->time);
 	if (isNumber == 1) {
-		self->time = PyFloat_AS_DOUBLE(PyNumber_Float(tmp));
-	}
+		self->time = PyNumber_Float(tmp);
+        self->modebuffer[3] = 0;
+    }
+    else {
+		self->time = tmp;
+        streamtmp = PyObject_CallMethod((PyObject *)self->time, "_getStream", NULL);
+        Py_INCREF(streamtmp);
+        Py_XDECREF(self->time_stream);
+        self->time_stream = (Stream *)streamtmp;
+        self->modebuffer[3] = 1;
+    }
 
-	Py_INCREF(Py_None);
-	return Py_None;
+	Py_RETURN_NONE;
 }
 
 static PyObject * SigTo_getServer(SigTo* self) { GET_SERVER };
@@ -619,6 +630,7 @@ static PyMemberDef SigTo_members[] = {
 {"server", T_OBJECT_EX, offsetof(SigTo, server), 0, "Pyo server."},
 {"stream", T_OBJECT_EX, offsetof(SigTo, stream), 0, "Stream object."},
 {"value", T_OBJECT_EX, offsetof(SigTo, value), 0, "Target value."},
+{"time", T_OBJECT_EX, offsetof(SigTo, time), 0, "Ramp time."},
 {"mul", T_OBJECT_EX, offsetof(SigTo, mul), 0, "Mul factor."},
 {"add", T_OBJECT_EX, offsetof(SigTo, add), 0, "Add factor."},
 {NULL}  /* Sentinel */
@@ -642,7 +654,7 @@ static PyNumberMethods SigTo_as_number = {
 (binaryfunc)SigTo_add,                      /*nb_add*/
 (binaryfunc)SigTo_sub,                 /*nb_subtract*/
 (binaryfunc)SigTo_multiply,                 /*nb_multiply*/
-(binaryfunc)SigTo_div,                   /*nb_divide*/
+INITIALIZE_NB_DIVIDE_ZERO               /*nb_divide*/
 0,                /*nb_remainder*/
 0,                   /*nb_divmod*/
 0,                   /*nb_power*/
@@ -656,16 +668,16 @@ static PyNumberMethods SigTo_as_number = {
 0,              /*nb_and*/
 0,              /*nb_xor*/
 0,               /*nb_or*/
-0,                                          /*nb_coerce*/
+INITIALIZE_NB_COERCE_ZERO                   /*nb_coerce*/
 0,                       /*nb_int*/
 0,                      /*nb_long*/
 0,                     /*nb_float*/
-0,                       /*nb_oct*/
-0,                       /*nb_hex*/
+INITIALIZE_NB_OCT_ZERO   /*nb_oct*/
+INITIALIZE_NB_HEX_ZERO   /*nb_hex*/
 (binaryfunc)SigTo_inplace_add,              /*inplace_add*/
 (binaryfunc)SigTo_inplace_sub,         /*inplace_subtract*/
 (binaryfunc)SigTo_inplace_multiply,         /*inplace_multiply*/
-(binaryfunc)SigTo_inplace_div,           /*inplace_divide*/
+INITIALIZE_NB_IN_PLACE_DIVIDE_ZERO        /*inplace_divide*/
 0,        /*inplace_remainder*/
 0,           /*inplace_power*/
 0,       /*inplace_lshift*/
@@ -674,15 +686,14 @@ static PyNumberMethods SigTo_as_number = {
 0,      /*inplace_xor*/
 0,       /*inplace_or*/
 0,             /*nb_floor_divide*/
-0,              /*nb_true_divide*/
+(binaryfunc)SigTo_div,                       /*nb_true_divide*/
 0,     /*nb_inplace_floor_divide*/
-0,      /*nb_inplace_true_divide*/
+(binaryfunc)SigTo_inplace_div,                       /*nb_inplace_true_divide*/
 0,                     /* nb_index */
 };
 
 PyTypeObject SigToType = {
-PyObject_HEAD_INIT(NULL)
-0,                         /*ob_size*/
+PyVarObject_HEAD_INIT(NULL, 0)
 "_pyo.SigTo_base",         /*tp_name*/
 sizeof(SigTo),         /*tp_basicsize*/
 0,                         /*tp_itemsize*/
@@ -690,7 +701,7 @@ sizeof(SigTo),         /*tp_basicsize*/
 0,                         /*tp_print*/
 0,                         /*tp_getattr*/
 0,                         /*tp_setattr*/
-0,                         /*tp_compare*/
+0,                         /*tp_as_async (tp_compare in Python 2)*/
 0,                         /*tp_repr*/
 &SigTo_as_number,             /*tp_as_number*/
 0,                         /*tp_as_sequence*/
@@ -870,7 +881,7 @@ VarPort_dealloc(VarPort* self)
 {
     pyo_DEALLOC
     VarPort_clear(self);
-    self->ob_type->tp_free((PyObject*)self);
+    Py_TYPE(self)->tp_free((PyObject*)self);
 }
 
 static PyObject *
@@ -949,17 +960,14 @@ VarPort_setValue(VarPort *self, PyObject *arg)
 {
 	PyObject *tmp;
 
-	if (arg == NULL) {
-		Py_INCREF(Py_None);
-		return Py_None;
-	}
+    ASSERT_ARG_NOT_NULL
 
 	int isNumber = PyNumber_Check(arg);
 
 	tmp = arg;
 	Py_INCREF(tmp);
 	if (isNumber == 1)
-		self->value = PyFloat_AsDouble(PyNumber_Float(tmp));
+		self->value = PyFloat_AsDouble(tmp);
     else
         self->value = self->lastValue;
 
@@ -972,17 +980,14 @@ VarPort_setTime(VarPort *self, PyObject *arg)
 {
 	PyObject *tmp;
 
-	if (arg == NULL) {
-		Py_INCREF(Py_None);
-		return Py_None;
-	}
+    ASSERT_ARG_NOT_NULL
 
 	int isNumber = PyNumber_Check(arg);
 
 	tmp = arg;
 	Py_INCREF(tmp);
 	if (isNumber == 1) {
-		self->time = PyFloat_AS_DOUBLE(PyNumber_Float(tmp));
+		self->time = PyFloat_AsDouble(tmp);
         self->timeStep = (long)(self->time * self->sr);
         self->timeout = (long)((self->time + 0.1) * self->sr);
 	}
@@ -1057,7 +1062,7 @@ static PyNumberMethods VarPort_as_number = {
     (binaryfunc)VarPort_add,                      /*nb_add*/
     (binaryfunc)VarPort_sub,                 /*nb_subtract*/
     (binaryfunc)VarPort_multiply,                 /*nb_multiply*/
-    (binaryfunc)VarPort_div,                   /*nb_divide*/
+    INITIALIZE_NB_DIVIDE_ZERO               /*nb_divide*/
     0,                /*nb_remainder*/
     0,                   /*nb_divmod*/
     0,                   /*nb_power*/
@@ -1071,16 +1076,16 @@ static PyNumberMethods VarPort_as_number = {
     0,              /*nb_and*/
     0,              /*nb_xor*/
     0,               /*nb_or*/
-    0,                                          /*nb_coerce*/
+    INITIALIZE_NB_COERCE_ZERO                   /*nb_coerce*/
     0,                       /*nb_int*/
     0,                      /*nb_long*/
     0,                     /*nb_float*/
-    0,                       /*nb_oct*/
-    0,                       /*nb_hex*/
+    INITIALIZE_NB_OCT_ZERO   /*nb_oct*/
+    INITIALIZE_NB_HEX_ZERO   /*nb_hex*/
     (binaryfunc)VarPort_inplace_add,              /*inplace_add*/
     (binaryfunc)VarPort_inplace_sub,         /*inplace_subtract*/
     (binaryfunc)VarPort_inplace_multiply,         /*inplace_multiply*/
-    (binaryfunc)VarPort_inplace_div,           /*inplace_divide*/
+    INITIALIZE_NB_IN_PLACE_DIVIDE_ZERO        /*inplace_divide*/
     0,        /*inplace_remainder*/
     0,           /*inplace_power*/
     0,       /*inplace_lshift*/
@@ -1089,15 +1094,14 @@ static PyNumberMethods VarPort_as_number = {
     0,      /*inplace_xor*/
     0,       /*inplace_or*/
     0,             /*nb_floor_divide*/
-    0,              /*nb_true_divide*/
+    (binaryfunc)VarPort_div,                       /*nb_true_divide*/
     0,     /*nb_inplace_floor_divide*/
-    0,      /*nb_inplace_true_divide*/
+    (binaryfunc)VarPort_inplace_div,                       /*nb_inplace_true_divide*/
     0,                     /* nb_index */
 };
 
 PyTypeObject VarPortType = {
-    PyObject_HEAD_INIT(NULL)
-    0,                         /*ob_size*/
+    PyVarObject_HEAD_INIT(NULL, 0)
     "_pyo.VarPort_base",         /*tp_name*/
     sizeof(VarPort),         /*tp_basicsize*/
     0,                         /*tp_itemsize*/
@@ -1105,7 +1109,7 @@ PyTypeObject VarPortType = {
     0,                         /*tp_print*/
     0,                         /*tp_getattr*/
     0,                         /*tp_setattr*/
-    0,                         /*tp_compare*/
+    0,                         /*tp_as_async (tp_compare in Python 2)*/
     0,                         /*tp_repr*/
     &VarPort_as_number,             /*tp_as_number*/
     0,                         /*tp_as_sequence*/
